==> imp-doc-2.0.1.tar.gz: html/classIMP_1_1em2d_1_1ProjectionFinder.js <==
var classIMP_1_1em2d_1_1ProjectionFinder =
[
    [ "ProjectionFinder", "classIMP_1_1em2d_1_1ProjectionFinder.html#a94bd0a6dcef8a6a568b1e34a3819cb21", null ],
    [ "do_preprocess_for_fast_coarse_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#abb1c43a0e5e08947d9c1dd10db5e511c", null ],
    [ "do_preprocess_projection", "classIMP_1_1em2d_1_1ProjectionFinder.html#a679131a2be9206131be9d89b12457720", null ],
    [ "do_preprocess_subject", "classIMP_1_1em2d_1_1ProjectionFinder.html#a388f284a8d2b21cc3d54d1e54cbb5a63", null ],
    [ "get_coarse_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#aecbc29de7d691a79a8eaaff440ad6baa", null ],
    [ "get_coarse_registration_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#afe068f5bdd538a76cf22718a2e04efee", null ],
    [ "get_coarse_registrations_for_subject", "classIMP_1_1em2d_1_1ProjectionFinder.html#af3e664255644a3fd5143c5b7ac8755be", null ],
    [ "get_complete_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#a6bf2e86816303b0eb4bd04d0c7cec917", null ],
    [ "get_fine_registration_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#aceb0282c429c5e9fb1f617a4b474e88f", null ],
    [ "get_global_score", "classIMP_1_1em2d_1_1ProjectionFinder.html#a653dd32b0620352b19d4bc6f21758126", null ],
    [ "get_number_of_projections", "classIMP_1_1em2d_1_1ProjectionFinder.html#a6b814b3b09783a39a84a402929017d60", null ],
    [ "get_number_of_subjects", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5c70bb409eaecc013d0d3cdd6bedebce", null ],
    [ "get_preprocessing_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5c9f2fa76b0ba5ddbb8c75f6a252166c", null ],
    [ "get_registration_results", "classIMP_1_1em2d_1_1ProjectionFinder.html#aee57c3e4e39a67d13e93c92b488340e2", null ],
    [ "get_save_match_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae15556628e3dd8a08edb344e02aefed4", null ],
    [ "set_fast_mode", "classIMP_1_1em2d_1_1ProjectionFinder.html#a177b68e1d5180244e3b8f8ada3055c7d", null ],
    [ "set_model_particles", "classIMP_1_1em2d_1_1ProjectionFinder.html#af750554814ed2896d3c65bee308e36db", null ],
    [ "set_number_of_class_averages_members", "classIMP_1_1em2d_1_1ProjectionFinder.html#a067222356065f5c9465bca502dce8494", null ],
    [ "set_projections", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae2fd66029152065fd368461492cc6b11", null ],
    [ "set_save_match_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5d9fe5d8cd056e216f37f8c4dcfbe5b9", null ],
    [ "set_subjects", "classIMP_1_1em2d_1_1ProjectionFinder.html#a7dd29466d12fc84818bef5ea38d9fd90", null ],
    [ "set_variance_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#a831a5befa05d173fbfa9d667f5196874", null ],
    [ "setup", "classIMP_1_1em2d_1_1ProjectionFinder.html#aff42f0cb55360eba23aca76e71cc25fd", null ],
    [ "show", "classIMP_1_1em2d_1_1ProjectionFinder.html#a48d745a9e23601bb0932acdb8a48a236", null ],
    [ "ProjectionFindersTemp", "classIMP_1_1em2d_1_1ProjectionFinder.html#afb45ef5024822ffef3a916d45a9ccd42", null ],
    [ "coarse_registration_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#aec3b971b61d4cd9be1a0afb9acec0ff3", null ],
    [ "fast_optimization_mode_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a70b72aa2dcb0714f11b451fbf7604229", null ],
    [ "fine_registration_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a835b3dcc9f09dab5035f142e602af5e7", null ],
    [ "masks_manager_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a83fcc942eda44e4e08244898c6ec6d43", null ],
    [ "model_particles_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a7ee2b6296c9414da664080354f4df4d5", null ],
    [ "n_members_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a662b4f93a9f56824974dd09f4e9dc56f", null ],
    [ "number_of_optimized_projections_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a21981557ead37a1d559dc07adbfef7ab", null ],
    [ "parameters_setup_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a83d288f03759e60ec628c4fa148bf5b7", null ],
    [ "params_", "classIMP_1_1em2d_1_1ProjectionFinder.html#aeb7530db67b53070c23f81e645d2a6aa", null ],
    [ "particles_set_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a53a95f0726834141c9d5f21a705ac50b", null ],
    [ "polar_params_", "classIMP_1_1em2d_1_1ProjectionFinder.html#adde9ab5209071e746380d9018495caae", null ],
    [ "preprocessing_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a3035ae7ea99e3275fba4e315b2125726", null ],
    [ "projections_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae69b481cd409d01c3110357ef874bc97", null ],
    [ "projections_cog_", "classIMP_1_1em2d_1_1ProjectionFinder.html#add4162c202b024bd7e985a1c04f12594", null ],
    [ "PROJECTIONS_POLAR_AUTOC_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a8b5ae38a9c3656ad9022d8eccc9339bc", null ],
    [ "registration_done_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a456fa37674f8d5a71f11022415e4e13c", null ],
    [ "registration_results_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ab32f8907a2c85187607d23a9ff3f0845", null ],
    [ "score_function_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a1f43ef70ec3bf753c4da7406a0b36a8e", null ],
    [ "subjects_", "classIMP_1_1em2d_1_1ProjectionFinder.html#afcfb81baf5ac05d42a5d75f203fc2cd1", null ],
    [ "SUBJECTS_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae79ebceb13e7ce9ccfd29625eb3c2fef", null ],
    [ "subjects_cog_", "classIMP_1_1em2d_1_1ProjectionFinder.html#af8367363aff2771aa3db22a8e3ada38c", null ],
    [ "SUBJECTS_POLAR_AUTOC_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a2c4666b7c8ec9ce386b1e8b5706589c2", null ],
    [ "variances_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a51ee4fd35e4d2df522a50a910ae4416c", null ]
];

==> imp-doc-2.1.0.tar.gz: html/classIMP_1_1em2d_1_1ProjectionFinder.js <==
var classIMP_1_1em2d_1_1ProjectionFinder =
[
    [ "ProjectionFinder", "classIMP_1_1em2d_1_1ProjectionFinder.html#a94bd0a6dcef8a6a568b1e34a3819cb21", null ],
    [ "do_preprocess_for_fast_coarse_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#abb1c43a0e5e08947d9c1dd10db5e511c", null ],
    [ "do_preprocess_projection", "classIMP_1_1em2d_1_1ProjectionFinder.html#a679131a2be9206131be9d89b12457720", null ],
    [ "do_preprocess_subject", "classIMP_1_1em2d_1_1ProjectionFinder.html#a388f284a8d2b21cc3d54d1e54cbb5a63", null ],
    [ "get_coarse_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#aecbc29de7d691a79a8eaaff440ad6baa", null ],
    [ "get_coarse_registration_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#afe068f5bdd538a76cf22718a2e04efee", null ],
    [ "get_coarse_registrations_for_subject", "classIMP_1_1em2d_1_1ProjectionFinder.html#af3e664255644a3fd5143c5b7ac8755be", null ],
    [ "get_complete_registration", "classIMP_1_1em2d_1_1ProjectionFinder.html#a6bf2e86816303b0eb4bd04d0c7cec917", null ],
    [ "get_fine_registration_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#aceb0282c429c5e9fb1f617a4b474e88f", null ],
    [ "get_global_score", "classIMP_1_1em2d_1_1ProjectionFinder.html#a653dd32b0620352b19d4bc6f21758126", null ],
    [ "get_number_of_projections", "classIMP_1_1em2d_1_1ProjectionFinder.html#a6b814b3b09783a39a84a402929017d60", null ],
    [ "get_number_of_subjects", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5c70bb409eaecc013d0d3cdd6bedebce", null ],
    [ "get_preprocessing_time", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5c9f2fa76b0ba5ddbb8c75f6a252166c", null ],
    [ "get_registration_results", "classIMP_1_1em2d_1_1ProjectionFinder.html#aee57c3e4e39a67d13e93c92b488340e2", null ],
    [ "get_save_match_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae15556628e3dd8a08edb344e02aefed4", null ],
    [ "get_type_name", "classIMP_1_1em2d_1_1ProjectionFinder.html#a91eb862345396d3b5be713f7f3887e02", null ],
    [ "get_version_info", "classIMP_1_1em2d_1_1ProjectionFinder.html#a84df4b70abc52c69622837c1df227022", null ],
    [ "set_fast_mode", "classIMP_1_1em2d_1_1ProjectionFinder.html#a177b68e1d5180244e3b8f8ada3055c7d", null ],
    [ "set_model_particles", "classIMP_1_1em2d_1_1ProjectionFinder.html#a1027494f847acdb8302fa6314ad5a02c", null ],
    [ "set_number_of_class_averages_members", "classIMP_1_1em2d_1_1ProjectionFinder.html#a067222356065f5c9465bca502dce8494", null ],
    [ "set_projections", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae2fd66029152065fd368461492cc6b11", null ],
    [ "set_save_match_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#a5d9fe5d8cd056e216f37f8c4dcfbe5b9", null ],
    [ "set_subjects", "classIMP_1_1em2d_1_1ProjectionFinder.html#a7dd29466d12fc84818bef5ea38d9fd90", null ],
    [ "set_variance_images", "classIMP_1_1em2d_1_1ProjectionFinder.html#a831a5befa05d173fbfa9d667f5196874", null ],
    [ "setup", "classIMP_1_1em2d_1_1ProjectionFinder.html#aff42f0cb55360eba23aca76e71cc25fd", null ],
    [ "show", "classIMP_1_1em2d_1_1ProjectionFinder.html#a48d745a9e23601bb0932acdb8a48a236", null ],
    [ "coarse_registration_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#aec3b971b61d4cd9be1a0afb9acec0ff3", null ],
    [ "fast_optimization_mode_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a70b72aa2dcb0714f11b451fbf7604229", null ],
    [ "fine_registration_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a835b3dcc9f09dab5035f142e602af5e7", null ],
    [ "masks_manager_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a83fcc942eda44e4e08244898c6ec6d43", null ],
    [ "model_particles_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ad6b5e5e2d9bf849fc4b1803a71ebe270", null ],
    [ "n_members_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a662b4f93a9f56824974dd09f4e9dc56f", null ],
    [ "number_of_optimized_projections_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a21981557ead37a1d559dc07adbfef7ab", null ],
    [ "parameters_setup_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a83d288f03759e60ec628c4fa148bf5b7", null ],
    [ "params_", "classIMP_1_1em2d_1_1ProjectionFinder.html#aeb7530db67b53070c23f81e645d2a6aa", null ],
    [ "particles_set_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a53a95f0726834141c9d5f21a705ac50b", null ],
    [ "polar_params_", "classIMP_1_1em2d_1_1ProjectionFinder.html#adde9ab5209071e746380d9018495caae", null ],
    [ "preprocessing_time_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a3035ae7ea99e3275fba4e315b2125726", null ],
    [ "projections_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae69b481cd409d01c3110357ef874bc97", null ],
    [ "projections_cog_", "classIMP_1_1em2d_1_1ProjectionFinder.html#add4162c202b024bd7e985a1c04f12594", null ],
    [ "PROJECTIONS_POLAR_AUTOC_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a8b5ae38a9c3656ad9022d8eccc9339bc", null ],
    [ "registration_done_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a456fa37674f8d5a71f11022415e4e13c", null ],
    [ "registration_results_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ab32f8907a2c85187607d23a9ff3f0845", null ],
    [ "score_function_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a9f3c3fea6244e696743b13d68802b7c1", null ],
    [ "subjects_", "classIMP_1_1em2d_1_1ProjectionFinder.html#afcfb81baf5ac05d42a5d75f203fc2cd1", null ],
    [ "SUBJECTS_", "classIMP_1_1em2d_1_1ProjectionFinder.html#ae79ebceb13e7ce9ccfd29625eb3c2fef", null ],
    [ "subjects_cog_", "classIMP_1_1em2d_1_1ProjectionFinder.html#af8367363aff2771aa3db22a8e3ada38c", null ],
    [ "SUBJECTS_POLAR_AUTOC_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a2c4666b7c8ec9ce386b1e8b5706589c2", null ],
    [ "variances_", "classIMP_1_1em2d_1_1ProjectionFinder.html#a51ee4fd35e4d2df522a50a910ae4416c", null ]
];
